Skip to content

Instantly share code, notes, and snippets.

@hughperkins
Created April 30, 2017 12:31
Show Gist options
  • Select an option

  • Save hughperkins/741e95ec3975a05d9efc46c289f33781 to your computer and use it in GitHub Desktop.

Select an option

Save hughperkins/741e95ec3975a05d9efc46c289f33781 to your computer and use it in GitHub Desktop.
args: ./easycl_unittests --gtest_filter=-SLOW*
Note: Google Test filter = -SLOW*
[==========] Running 63 tests from 25 test cases.
[----------] Global test environment set-up.
[----------] 1 test from testscalars
[ RUN ] testscalars.test1
found opencl library
Using Apple , OpenCL platform: Apple
Using OpenCL device: Intel(R) HD Graphics 530
-156 -155 -154 -153 -152
3000 3001 3002 3003 3004
-2524653 -2524652 -2524651 -2524650 -2524649
1353523545 1353523546 1353523547 1353523548 1353523549
1.234 2.234 3.234 4.234 5.234
tests completed ok
[ OK ] testscalars.test1 (158 ms)
[----------] 1 test from testscalars (158 ms total)
[----------] 1 test from testintarray
[ RUN ] testintarray.main
found opencl library
Using Apple , OpenCL platform: Apple
Using OpenCL device: Intel(R) HD Graphics 530
5 8 26 14 17
7 10 34 16 19
tests completed ok
[ OK ] testintarray.main (125 ms)
[----------] 1 test from testintarray (125 ms total)
[----------] 3 tests from testfloatwrapper
[ RUN ] testfloatwrapper.main
found opencl library
Using Apple , OpenCL platform: Apple
Using OpenCL device: Intel(R) HD Graphics 530
tests completed ok
[ OK ] testfloatwrapper.main (137 ms)
[ RUN ] testfloatwrapper.singlecopytodevice
Using Apple , OpenCL platform: Apple
Using OpenCL device: Intel(R) HD Graphics 530
[ OK ] testfloatwrapper.singlecopytodevice (3 ms)
[ RUN ] testfloatwrapper.doublecopytodevice
Using Apple , OpenCL platform: Apple
Using OpenCL device: Intel(R) HD Graphics 530
[ OK ] testfloatwrapper.doublecopytodevice (4 ms)
[----------] 3 tests from testfloatwrapper (144 ms total)
[----------] 2 tests from testqueues
[ RUN ] testqueues.main
start
found opencl library
Using Apple , OpenCL platform: Apple
Using OpenCL device: Intel(R) HD Graphics 530
tests completed ok
[ OK ] testqueues.main (148 ms)
[ RUN ] testqueues.defaultqueue
start
found opencl library
Using Apple , OpenCL platform: Apple
Using OpenCL device: Intel(R) HD Graphics 530
cl->queue 0x7fa84240aad0
*cl->queue 0x7fa84240aff0
cl->default_queue->queue0x7fa84240aff0
tests completed ok
[ OK ] testqueues.defaultqueue (144 ms)
[----------] 2 tests from testqueues (293 ms total)
[----------] 1 test from testclarray
[ RUN ] testclarray.main
found opencl library
Using Apple , OpenCL platform: Apple
Using OpenCL device: Intel(R) HD Graphics 530
tests completed ok
[ OK ] testclarray.main (146 ms)
[----------] 1 test from testclarray (146 ms total)
[----------] 1 test from testfloatwrapperconst
[ RUN ] testfloatwrapperconst.main
found opencl library
Using Apple , OpenCL platform: Apple
Using OpenCL device: Intel(R) HD Graphics 530
tests completed ok
[ OK ] testfloatwrapperconst.main (150 ms)
[----------] 1 test from testfloatwrapperconst (150 ms total)
[----------] 1 test from testintwrapper
[ RUN ] testintwrapper.main
found opencl library
Using Apple , OpenCL platform: Apple
Using OpenCL device: Intel(R) HD Graphics 530
tests completed ok
[ OK ] testintwrapper.main (133 ms)
[----------] 1 test from testintwrapper (133 ms total)
[----------] 1 test from test_scenario_te42kyfo
[ RUN ] test_scenario_te42kyfo.main
Using Apple , OpenCL platform: Apple
Using OpenCL device: Intel(R) HD Graphics 530
finished
[ OK ] test_scenario_te42kyfo.main (222 ms)
[----------] 1 test from test_scenario_te42kyfo (222 ms total)
[----------] 1 test from testfloatarray
[ RUN ] testfloatarray.main
found opencl library
Using Apple , OpenCL platform: Apple
Using OpenCL device: Intel(R) HD Graphics 530
5 8 26 14 17
7 10 34 16 19
tests completed ok
[ OK ] testfloatarray.main (138 ms)
[----------] 1 test from testfloatarray (138 ms total)
[----------] 2 tests from testeasycl
[ RUN ] testeasycl.main
start
found opencl library
Using Apple , OpenCL platform: Apple
Using OpenCL device: Intel(R) HD Graphics 530
tests completed ok
[ OK ] testeasycl.main (4 ms)
[ RUN ] testeasycl.power2helper
[ OK ] testeasycl.power2helper (0 ms)
[----------] 2 tests from testeasycl (4 ms total)
[----------] 1 test from testinout
[ RUN ] testinout.main
found opencl library
Using Apple , OpenCL platform: Apple
Using OpenCL device: Intel(R) HD Graphics 530
tests completed ok
[ OK ] testinout.main (136 ms)
[----------] 1 test from testinout (137 ms total)
[----------] 7 tests from testlocal
[ RUN ] testlocal.uselocal
Using Apple , OpenCL platform: Apple
Using OpenCL device: Intel(R) HD Graphics 530
[ OK ] testlocal.uselocal (161 ms)
[ RUN ] testlocal.notUselocal
Using Apple , OpenCL platform: Apple
Using OpenCL device: Intel(R) HD Graphics 530
[ OK ] testlocal.notUselocal (153 ms)
[ RUN ] testlocal.globalreduce
Using Apple , OpenCL platform: Apple
Using OpenCL device: Intel(R) HD Graphics 530
[ OK ] testlocal.globalreduce (1256 ms)
[ RUN ] testlocal.localreduce
Using Apple , OpenCL platform: Apple
Using OpenCL device: Intel(R) HD Graphics 530
[ OK ] testlocal.localreduce (791 ms)
[ RUN ] testlocal.reduceviascratch_multipleworkgroups
Using Apple , OpenCL platform: Apple
Using OpenCL device: Intel(R) HD Graphics 530
expected sum, calc'd via cpu, : 294906
[ OK ] testlocal.reduceviascratch_multipleworkgroups (175 ms)
[ RUN ] testlocal.reduceviascratch_multipleworkgroups_ints
Using Apple , OpenCL platform: Apple
Using OpenCL device: Intel(R) HD Graphics 530
numworkgroups 256 workgroupsize 256 N 65536
[ OK ] testlocal.reduceviascratch_multipleworkgroups_ints (5 ms)
[ RUN ] testlocal.reduce_multipleworkgroups_ints_noscratch
Using Apple , OpenCL platform: Apple
Using OpenCL device: Intel(R) HD Graphics 530
numworkgroups 256 workgroupsize 256 N 65536
[ OK ] testlocal.reduce_multipleworkgroups_ints_noscratch (5 ms)
[----------] 7 tests from testlocal (2549 ms total)
[----------] 1 test from testdefines
[ RUN ] testdefines.simple
Using Apple , OpenCL platform: Apple
Using OpenCL device: Intel(R) HD Graphics 530
[ OK ] testdefines.simple (147 ms)
[----------] 1 test from testdefines (147 ms total)
[----------] 1 test from testbuildlog
[ RUN ] testbuildlog.main
Using Apple , OpenCL platform: Apple
Using OpenCL device: Intel(R) HD Graphics 530
testbuildlog.cl build log:
<program source>:2:4: error: use of undeclared identifier 'someerrorxyz'
someerrorxyz;
^
kernel build error:
kernel source:
1: kernel void foo() {
2: someerrorxyz;
3: }
4:
5:
Something went wrong with clCreateKernel, OpenCL erorr code -45
testbuildlog.cl build log:
<program source>:2:4: error: use of undeclared identifier 'someerrorxyz'
someerrorxyz;
^
kernel source:
1: kernel void foo() {
2: someerrorxyz;
3: }
4:
5:
Something went wrong with clCreateKernel, OpenCL erorr code -45
testbuildlog.cl build log:
<program source>:2:4: error: use of undeclared identifier 'someerrorxyz'
someerrorxyz;
^
[ OK ] testbuildlog.main (91 ms)
[----------] 1 test from testbuildlog (91 ms total)
[----------] 5 tests from testnewinstantiations
[ RUN ] testnewinstantiations.createForFirstGpu
Using Apple , OpenCL platform: Apple
Using OpenCL device: Intel(R) HD Graphics 530
[ OK ] testnewinstantiations.createForFirstGpu (147 ms)
[ RUN ] testnewinstantiations.createForIndexedGpu
Using Apple , OpenCL platform: Apple
Using OpenCL device: Intel(R) HD Graphics 530
[ OK ] testnewinstantiations.createForIndexedGpu (152 ms)
[ RUN ] testnewinstantiations.createForIndexedDevice
num platforms 1
checking platform id 0x7fff0000
num devices 3
Using Apple , OpenCL platform: Apple
Using OpenCL device: Intel(R) Core(TM) i7-6700HQ CPU @ 2.60GHz
Using Apple , OpenCL platform: Apple
Using OpenCL device: Intel(R) HD Graphics 530
Using Apple , OpenCL platform: Apple
Using OpenCL device: AMD Radeon Pro 450 Compute Engine
[ OK ] testnewinstantiations.createForIndexedDevice (793 ms)
[ RUN ] testnewinstantiations.createForPlatformDeviceIndexes
Using Apple , OpenCL platform: Apple
Using OpenCL device: Intel(R) Core(TM) i7-6700HQ CPU @ 2.60GHz
[ OK ] testnewinstantiations.createForPlatformDeviceIndexes (1 ms)
[ RUN ] testnewinstantiations.createForFirstGpuOtherwiseCpu
Using Apple , OpenCL platform: Apple
Using OpenCL device: Intel(R) HD Graphics 530
[ OK ] testnewinstantiations.createForFirstGpuOtherwiseCpu (149 ms)
[----------] 5 tests from testnewinstantiations (1244 ms total)
[----------] 1 test from testucharwrapper
[ RUN ] testucharwrapper.main
found opencl library
Using Apple , OpenCL platform: Apple
Using OpenCL device: Intel(R) HD Graphics 530
tests completed ok
[ OK ] testucharwrapper.main (159 ms)
[----------] 1 test from testucharwrapper (159 ms total)
[----------] 2 tests from testkernelstore
[ RUN ] testkernelstore.main
found opencl library
Using Apple , OpenCL platform: Apple
Using OpenCL device: Intel(R) HD Graphics 530
[ OK ] testkernelstore.main (144 ms)
[ RUN ] testkernelstore.cl_deletes
found opencl library
Using Apple , OpenCL platform: Apple
Using OpenCL device: Intel(R) HD Graphics 530
[ OK ] testkernelstore.cl_deletes (128 ms)
[----------] 2 tests from testkernelstore (274 ms total)
[----------] 1 test from testdirtywrapper
[ RUN ] testdirtywrapper.main
found opencl library
Using Apple , OpenCL platform: Apple
Using OpenCL device: Intel(R) HD Graphics 530
tests completed ok
[ OK ] testdirtywrapper.main (142 ms)
[----------] 1 test from testdirtywrapper (142 ms total)
[----------] 2 tests from testDeviceInfo
[ RUN ] testDeviceInfo.basic
num platforms 1
checking platform id 0x7fff0000
num devices 3
numdevices 3
checking platform id 0x7fff0000
num devices this platform 3
platformVendor: Apple
platformName: Apple
deviceType: 2
globalMemSize: 17179869184
localMemSize: 32768
globalMemCachelineSize: 6291456
maxMemAllocSize: 4294967296
maxComputeUnits: 8
maxWorkGroupSize: 1024
maxWorkItemDimensions: 3
deviceName: Intel(R) Core(TM) i7-6700HQ CPU @ 2.60GHz
openClCVersion: OpenCL C 1.2
deviceVersion: OpenCL 1.2
maxClockFrequency: 2600
checking platform id 0x7fff0000
num devices this platform 3
platformVendor: Apple
platformName: Apple
deviceType: 4
globalMemSize: 1610612736
localMemSize: 65536
globalMemCachelineSize: 0
maxMemAllocSize: 402653184
maxComputeUnits: 24
maxWorkGroupSize: 256
maxWorkItemDimensions: 3
deviceName: Intel(R) HD Graphics 530
openClCVersion: OpenCL C 1.2
deviceVersion: OpenCL 1.2
maxClockFrequency: 1050
checking platform id 0x7fff0000
num devices this platform 3
platformVendor: Apple
platformName: Apple
deviceType: 4
globalMemSize: 2147483648
localMemSize: 32768
globalMemCachelineSize: 0
maxMemAllocSize: 536870912
maxComputeUnits: 10
maxWorkGroupSize: 256
maxWorkItemDimensions: 3
deviceName: AMD Radeon Pro 450 Compute Engine
openClCVersion: OpenCL C 1.2
deviceVersion: OpenCL 1.2
maxClockFrequency: 800
[ OK ] testDeviceInfo.basic (1 ms)
[ RUN ] testDeviceInfo.gpus
num platforms 1
checking platform id 0x7fff0000
num devices 3
checking platform id 0x7fff0000
num devices this platform 2
platformVendor: Apple
platformName: Apple
deviceType: 4
globalMemSize: 1610612736
localMemSize: 65536
globalMemCachelineSize: 0
maxMemAllocSize: 402653184
maxComputeUnits: 24
maxWorkGroupSize: 256
maxWorkItemDimensions: 3
deviceName: Intel(R) HD Graphics 530
openClCVersion: OpenCL C 1.2
deviceVersion: OpenCL 1.2
maxClockFrequency: 1050
checking platform id 0x7fff0000
num devices this platform 2
platformVendor: Apple
platformName: Apple
deviceType: 4
globalMemSize: 2147483648
localMemSize: 32768
globalMemCachelineSize: 0
maxMemAllocSize: 536870912
maxComputeUnits: 10
maxWorkGroupSize: 256
maxWorkItemDimensions: 3
deviceName: AMD Radeon Pro 450 Compute Engine
openClCVersion: OpenCL C 1.2
deviceVersion: OpenCL 1.2
maxClockFrequency: 800
checking platform id 0x7fff0000
num devices this platform 2
unknown file: Failure
C++ exception with description "Not enough devices found to satisfy index: 2" thrown in the test body.
[ FAILED ] testDeviceInfo.gpus (1 ms)
[----------] 2 tests from testDeviceInfo (2 ms total)
[----------] 11 tests from testLuaTemplater
[ RUN ] testLuaTemplater.basicsubstitution1
This is my 3 template.
[ OK ] testLuaTemplater.basicsubstitution1 (1 ms)
[ RUN ] testLuaTemplater.basicsubstitution1b
This is my 3 template
[ OK ] testLuaTemplater.basicsubstitution1b (0 ms)
[ RUN ] testLuaTemplater.basicsubstitution
This is my 3 template. It's 123...
Today's weather is rain.
[ OK ] testLuaTemplater.basicsubstitution (1 ms)
[ RUN ] testLuaTemplater.startofsection
3 template
[ OK ] testLuaTemplater.startofsection (1 ms)
[ RUN ] testLuaTemplater.endofsection
template 3
[ OK ] testLuaTemplater.endofsection (1 ms)
[ RUN ] testLuaTemplater.loop
a[0] = image[0];
a[1] = image[1];
a[2] = image[2];
[ OK ] testLuaTemplater.loop (1 ms)
[ RUN ] testLuaTemplater.nestedloop
[
a[0] = image[0];
b[0] = image[0];
b[1] = image[1];
a[1] = image[1];
b[0] = image[0];
b[1] = image[1];
a[2] = image[2];
b[0] = image[0];
b[1] = image[1];
]
[ OK ] testLuaTemplater.nestedloop (0 ms)
[ RUN ] testLuaTemplater.foreachloop
[
blue
green
red
]
[ OK ] testLuaTemplater.foreachloop (1 ms)
[ RUN ] testLuaTemplater.codesection
[
2
]
[ OK ] testLuaTemplater.codesection (1 ms)
[ RUN ] testLuaTemplater.codingerror
Error
Incoming template:
{%
sum=foo.blah
%}
intemediate form (this is just pure Lua code, you can run this in lua, see what happens):
1: _ret = {}
2: _ret[#_ret+1] = [[
3: ]]
4: sum=foo.blah
5: _ret[#_ret+1] = [[
6: ]]
7: return table.concat(_ret)
err [string "_ret = {}..."]:7: attempt to index global 'foo' (a nil value)
error: [string "-- adapted from https://john.nachtimwald.co..."]:164: [string "_ret = {}..."]:7: attempt to index global 'foo' (a nil value)
[ OK ] testLuaTemplater.codingerror (1 ms)
[ RUN ] testLuaTemplater.include
[
var color = 'blue';
var blah = 0;
]
[ OK ] testLuaTemplater.include (1 ms)
[----------] 11 tests from testLuaTemplater (9 ms total)
[----------] 9 tests from testTemplatedKernel
[ RUN ] testTemplatedKernel.basic
Using Apple , OpenCL platform: Apple
Using OpenCL device: Intel(R) HD Graphics 530
[ OK ] testTemplatedKernel.basic (291 ms)
[ RUN ] testTemplatedKernel.withbuilderror
Using Apple , OpenCL platform: Apple
Using OpenCL device: Intel(R) HD Graphics 530
kernel build error:
kernel source:
1: kernel void doStuff(int N, global int *out, global const int *in) {
2: int globalId = get_global_id(0);
3: if(globalId < N) {
4: int value = in[globalId];
5: out[globalId] = value;
6: }
7: }
8:
Invalid kernel name, code -46, kernel doStuffaaa
caught error:
kernel source:
1: kernel void doStuff(int N, global int *out, global const int *in) {
2: int globalId = get_global_id(0);
3: if(globalId < N) {
4: int value = in[globalId];
5: out[globalId] = value;
6: }
7: }
8:
Invalid kernel name, code -46, kernel doStuffaaa
[ OK ] testTemplatedKernel.withbuilderror (8 ms)
[ RUN ] testTemplatedKernel.withtemplateerror
Using Apple , OpenCL platform: Apple
Using OpenCL device: Intel(R) HD Graphics 530
Error
Incoming template:
kernel void doStuff(int N, global {{type}} *out, global const {{type}} *in) {
int globalId = get_global_id(0);
if(globalId < N) {
{{type}} value = in[globalId];
out[globalId] = value;
}
}
intemediate form (this is just pure Lua code, you can run this in lua, see what happens):
1: _ret = {}
2: _ret[#_ret+1] = [[
3: kernel void doStuff(int N, global ]]
4: _ret[#_ret+1] = type
5: _ret[#_ret+1] = [[
6: *out, global const ]]
7: _ret[#_ret+1] = type
8: _ret[#_ret+1] = [[
9: *in) {
10: int globalId = get_global_id(0);
11: if(globalId < N) {
12: ]]
13: _ret[#_ret+1] = type
14: _ret[#_ret+1] = [[
15: value = in[globalId];
16: out[globalId] = value;
17: }
18: }
19: ]]
20: return table.concat(_ret)
err [string "_ret = {}..."]:21: invalid value (function) at index 2 in table for 'concat'
error: [string "-- adapted from https://john.nachtimwald.co..."]:164: [string "_ret = {}..."]:21: invalid value (function) at index 2 in table for 'concat'
caught error: Error: [string "-- adapted from https://john.nachtimwald.co..."]:164: [string "_ret = {}..."]:21: invalid value (function) at index 2 in table for 'concat'
[ OK ] testTemplatedKernel.withtemplateerror (3 ms)
[ RUN ] testTemplatedKernel.withbuilderrorintargs
Using Apple , OpenCL platform: Apple
Using OpenCL device: Intel(R) HD Graphics 530
testfile build log:
<program source>:2:6: warning: no previous prototype for function 'op'
void op() {}
^
<program source>:4:7: warning: too many arguments in call to 'op'
op(N)
~~ ^
<program source>:4:8: error: expected ';' after expression
op(N)
^
;
kernel build error:
kernel source:
1:
2: void op() {}
3: kernel void doStuff(int N, global float *a) {
4: op(N)
5: }
6:
Something went wrong with clCreateKernel, OpenCL erorr code -45
testfile build log:
<program source>:2:6: warning: no previous prototype for function 'op'
void op() {}
^
<program source>:4:7: warning: too many arguments in call to 'op'
op(N)
~~ ^
<program source>:4:8: error: expected ';' after expression
op(N)
^
;
caught error:
kernel source:
1:
2: void op() {}
3: kernel void doStuff(int N, global float *a) {
4: op(N)
5: }
6:
Something went wrong with clCreateKernel, OpenCL erorr code -45
testfile build log:
<program source>:2:6: warning: no previous prototype for function 'op'
void op() {}
^
<program source>:4:7: warning: too many arguments in call to 'op'
op(N)
~~ ^
<program source>:4:8: error: expected ';' after expression
op(N)
^
;
[ OK ] testTemplatedKernel.withbuilderrorintargs (95 ms)
[ RUN ] testTemplatedKernel.withargserror
Using Apple , OpenCL platform: Apple
Using OpenCL device: Intel(R) HD Graphics 530
caught error:
kernel source:
1: kernel void doStuff(int N, global int *out, global const int *in) {
2: int globalId = get_global_id(0);
3: if(globalId < N) {
4: int value = in[globalId];
5: out[globalId] = value;
6: }
7: }
8:
Invalid kernel args, code -52
[ OK ] testTemplatedKernel.withargserror (159 ms)
[ RUN ] testTemplatedKernel.basic2
Using Apple , OpenCL platform: Apple
Using OpenCL device: Intel(R) HD Graphics 530
i=0 a[0]=0
i=1 a[0]=1
i=2 a[0]=2
i=3 a[0]=3
i=4 a[0]=4
i=5 a[0]=5
i=6 a[0]=6
i=7 a[0]=7
i=8 a[0]=8
i=9 a[0]=9
[ OK ] testTemplatedKernel.basic2 (1750 ms)
[ RUN ] testTemplatedKernel.foreach
Using Apple , OpenCL platform: Apple
Using OpenCL device: Intel(R) HD Graphics 530
testfile build log:
<program source>:6:16: warning: unused variable 'blue'
int blue = 0;
^
<program source>:8:16: warning: unused variable 'red'
int red = 0;
^
<program source>:10:16: warning: unused variable 'green'
int green = 0;
^
[ OK ] testTemplatedKernel.foreach (147 ms)
[ RUN ] testTemplatedKernel.forrange
Using Apple , OpenCL platform: Apple
Using OpenCL device: Intel(R) HD Graphics 530
testfile build log:
<program source>:6:16: warning: unused variable 'a0'
int a0 = 0;
^
<program source>:8:16: warning: unused variable 'a1'
int a1 = 0;
^
<program source>:10:16: warning: unused variable 'a2'
int a2 = 0;
^
<program source>:12:16: warning: unused variable 'a3'
int a3 = 0;
^
<program source>:14:16: warning: unused variable 'a4'
int a4 = 0;
^
[ OK ] testTemplatedKernel.forrange (141 ms)
[ RUN ] testTemplatedKernel.forrange2
Using Apple , OpenCL platform: Apple
Using OpenCL device: Intel(R) HD Graphics 530
kernel void doStuff(
int t11,
int t12,
int t21,
int t22,
int t23,
int count
) {
}
[ OK ] testTemplatedKernel.forrange2 (128 ms)
[----------] 9 tests from testTemplatedKernel (2725 ms total)
[----------] 1 test from testStructs
[ RUN ] testStructs.main
found opencl library
Using Apple , OpenCL platform: Apple
Using OpenCL device: Intel(R) HD Graphics 530
ints[0] 13
floats[0] 1.234
mystruct.threeints[0]=9
[ OK ] testStructs.main (141 ms)
[----------] 1 test from testStructs (141 ms total)
[----------] 2 tests from testprofiling
[ RUN ] testprofiling.basic
found opencl library
Using Apple , OpenCL platform: Apple
Using OpenCL device: Intel(R) HD Graphics 530
source1.test 76.1577ms
source2.test 10.5797ms
source3.test 2.39424ms
source4.test 0.43048ms
[ OK ] testprofiling.basic (288 ms)
[ RUN ] testprofiling.noprofiling
found opencl library
Using Apple , OpenCL platform: Apple
Using OpenCL device: Intel(R) HD Graphics 530
[ OK ] testprofiling.noprofiling (5 ms)
[----------] 2 tests from testprofiling (293 ms total)
[----------] 3 tests from testcopybuffer
[ RUN ] testcopybuffer.main
found opencl library
Using Apple , OpenCL platform: Apple
Using OpenCL device: Intel(R) HD Graphics 530
[ OK ] testcopybuffer.main (4 ms)
[ RUN ] testcopybuffer.withoffset
found opencl library
Using Apple , OpenCL platform: Apple
Using OpenCL device: Intel(R) HD Graphics 530
[ OK ] testcopybuffer.withoffset (4 ms)
[ RUN ] testcopybuffer.throwsifnotondevice
found opencl library
Using Apple , OpenCL platform: Apple
Using OpenCL device: Intel(R) HD Graphics 530
[ OK ] testcopybuffer.throwsifnotondevice (4 ms)
[----------] 3 tests from testcopybuffer (13 ms total)
[----------] 2 tests from teststatefultimer
[ RUN ] teststatefultimer.basic
found opencl library
Using Apple , OpenCL platform: Apple
Using OpenCL device: Intel(R) HD Graphics 530
statefultimer v0.7
dump enabled=1
StatefulTimer readings:
dump enabled=1
StatefulTimer readings:
end: 77.2642ms count=1
foo: 0.102783ms count=16
start: 0.222168ms count=1
time: 77.377
[ OK ] teststatefultimer.basic (296 ms)
[ RUN ] teststatefultimer.notiming
found opencl library
Using Apple , OpenCL platform: Apple
Using OpenCL device: Intel(R) HD Graphics 530
dump enabled=0
dump enabled=0
time: 81.314
[ OK ] teststatefultimer.notiming (315 ms)
[----------] 2 tests from teststatefultimer (611 ms total)
[----------] Global test environment tear-down
[==========] 63 tests from 25 test cases ran. (10053 ms total)
[ PASSED ] 62 tests.
[ FAILED ] 1 test, listed below:
[ FAILED ] testDeviceInfo.gpus
1 FAILED TEST
Sign up for free to join this conversation on GitHub. Already have an account? Sign in to comment